==> aws-cdk.aws-lex-1.137.0.tar.gz: package/lib/lex-canned-metrics.generated.d.ts <==
export declare class LexMetrics {
    static runtimeRequestCountSum(dimensions: {
        BotAlias: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
        };
        statistic: string;
    };
    static runtimeSucessfulRequestLatencyAverage(dimensions: {
        BotAlias: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
        };
        statistic: string;
    };
    static runtimeInvalidLambdaResponsesSum(dimensions: {
        BotAlias: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
        };
        statistic: string;
    };
    static runtimeLambdaErrorsSum(dimensions: {
        BotAlias: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
        };
        statistic: string;
    };
    static missedUtteranceCountSum(dimensions: {
        BotAlias: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
        };
        statistic: string;
    };
    static runtimePollyErrorsSum(dimensions: {
        BotAlias: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
        };
        statistic: string;
    };
    static runtimeSystemErrorsSum(dimensions: {
        BotAlias: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
        };
        statistic: string;
    };
    static runtimeThrottledEventsSum(dimensions: {
        BotAlias: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
        };
        statistic: string;
    };
    static runtimeUserErrorsSum(dimensions: {
        BotAlias: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
        };
        statistic: string;
    };
}

==> aws-cdk.aws-lex-1.143.0.tar.gz: package/lib/lex-canned-metrics.generated.d.ts <==
export declare class LexMetrics {
    static runtimeRequestCountSum(dimensions: {
        BotAlias: string;
        BotName: string;
        Operation: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
            BotName: string;
            Operation: string;
        };
        statistic: string;
    };
    static runtimeSuccessfulRequestLatencyAverage(dimensions: {
        BotAlias: string;
        BotName: string;
        Operation: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
            BotName: string;
            Operation: string;
        };
        statistic: string;
    };
    static runtimeInvalidLambdaResponsesSum(dimensions: {
        BotAlias: string;
        BotName: string;
        Operation: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
            BotName: string;
            Operation: string;
        };
        statistic: string;
    };
    static runtimeLambdaErrorsSum(dimensions: {
        BotAlias: string;
        BotName: string;
        Operation: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
            BotName: string;
            Operation: string;
        };
        statistic: string;
    };
    static missedUtteranceCountSum(dimensions: {
        BotAlias: string;
        BotName: string;
        Operation: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
            BotName: string;
            Operation: string;
        };
        statistic: string;
    };
    static runtimePollyErrorsSum(dimensions: {
        BotAlias: string;
        BotName: string;
        Operation: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
            BotName: string;
            Operation: string;
        };
        statistic: string;
    };
    static runtimeSystemErrorsSum(dimensions: {
        BotAlias: string;
        BotName: string;
        Operation: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
            BotName: string;
            Operation: string;
        };
        statistic: string;
    };
    static runtimeThrottledEventsSum(dimensions: {
        BotAlias: string;
        BotName: string;
        Operation: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
            BotName: string;
            Operation: string;
        };
        statistic: string;
    };
    static runtimeUserErrorsSum(dimensions: {
        BotAlias: string;
        BotName: string;
        Operation: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            BotAlias: string;
            BotName: string;
            Operation: string;
        };
        statistic: string;
    };
}
